from setuptools import setup

setup(
    name='uh_custom_logger',
    version='0.0.2',
    description='A custom logging utility for uh projects.',
    author='Necip Asik',
    author_email='data@universityhousing.nl',
    packages=['uh_custom_logger'],  # same as name
)
